@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagetest.h"
@@ -29,11 +16,11 @@ QTEST_MAIN(MessageTest)
 
 void MessageTest::testMainBodyPart()
 {
-    Message *msg = new Message();
-    Message *msg2 = new Message();
-    Content *text = new Content();
+    auto *msg = new Message();
+    auto *msg2 = new Message();
+    auto *text = new Content();
     text->contentType()->setMimeType("text/plain");
-    Content *html = new Content();
+    auto *html = new Content();
     html->contentType()->setMimeType("text/html");
 
     // empty message
@@ -71,10 +58,10 @@ void MessageTest::testMainBodyPart()
     QCOMPARE(msg->mainBodyPart("text/html"), html);
 
     // mulitpart/alternative inside multipart/mixed
-    Message *msg3 = new Message();
+    auto *msg3 = new Message();
     msg3->contentType()->setMimeType("multipart/mixed");
     msg3->addContent(msg);
-    Content *attach = new Content();
+    auto *attach = new Content();
     attach->contentType()->setMimeType("text/plain");
 
     QCOMPARE(msg3->mainBodyPart(), html);
@@ -100,7 +87,7 @@ void MessageTest::testBrunosMultiAssembleBug()
         "\n"
         "body";
 
-    Message *msg = new Message;
+    auto *msg = new Message;
     msg->setContent(data);
     msg->parse();
     msg->assemble();
@@ -131,7 +118,7 @@ void MessageTest::testWillsAndTillsCrash()
                             "X-KMail-SignatureState:\n"
                             "X-KMail-MDN-Sent:\n\n";
 
-    KMime::Message *msg = new KMime::Message;
+    auto *msg = new KMime::Message;
     msg->setContent(deadlyMail);
     msg->parse();
     QVERIFY(!msg->date()->isEmpty());
@@ -157,7 +144,7 @@ void MessageTest::testHeaderFieldWithoutSpace()
 {
     // Headers without a space, like the CC header here, are allowed according to
     // the examples in RFC2822, Appendix A5
-    QString mail = QStringLiteral("From:\n"
+    const QString mail = QStringLiteral("From:\n"
                                  "To: heinz@test.de\n"
                                  "Cc:moritz@test.de\n"
                                  "Subject: Test\n"
@@ -178,7 +165,7 @@ void MessageTest::testWronglyFoldedHeaders()
 {
     // The first subject line here doesn't contain anything. This is invalid,
     // however there are some mailers out there that produce those messages.
-    QString mail = QStringLiteral("Subject:\n"
+    const QString mail = QStringLiteral("Subject:\n"
                                  " Hello\n"
                                  " World\n"
                                  "To: \n"
@@ -197,8 +184,8 @@ void MessageTest::missingHeadersTest()
 {
     // Test that the message body is OK even though some headers are missing
     KMime::Message msg;
-    QString body = QStringLiteral("Hi Donald, look at those nice pictures I found!\n");
-    QString content = QLatin1String("From: georgebush@whitehouse.org\n"
+    const QString body = QStringLiteral("Hi Donald, look at those nice pictures I found!\n");
+    const QString content = QLatin1String("From: georgebush@whitehouse.org\n"
                                     "To: donaldrumsfeld@whitehouse.org\n"
                                     "Subject: Cute Kittens\n"
                                     "\n") + body;
@@ -311,7 +298,7 @@ void MessageTest::testUtf16()
     QCOMPARE(msg.decodedText(false, true), QLatin1String("This is UTF-16 Text."));
 
     // Add a new To header, for testings
-    KMime::Headers::To *to = new KMime::Headers::To;
+    auto *to = new KMime::Headers::To;
     KMime::Types::Mailbox address;
     address.setAddress("test@test.de");
     address.setName(QStringLiteral("Fränz Töster"));
@@ -365,7 +352,7 @@ void MessageTest::testDecodedText()
 
 void MessageTest::testInlineImages()
 {
-    QByteArray data =
+    const QByteArray data =
         "From: <kde@kde.org>\n"
         "To: kde@kde.org\n"
         "Subject: Inline Image (unsigned)\n"
@@ -698,9 +685,9 @@ void MessageTest::testBugAttachment387423()
 void MessageTest::testCrashReplyInvalidEmail()
 {
     KMime::Message::Ptr msg = readAndParseMail(QStringLiteral("crash-invalid-email-reply.mbox"));
-
     QCOMPARE(msg->subject()->as7BitString().data(), "Subject: Re: Authorization required to post to gmane.network.wireguard (b96565298414a43aabcf9fbedf5e7e27)");
-    QEXPECT_FAIL("", "Problem with content type", Continue);
-    QCOMPARE(msg->contents().size(), 2);
+    QCOMPARE(msg->contentType()->mimeType().data(), "text/plain");
+    QCOMPARE(msg->contentType()->charset().data(), "us-ascii");
+    QVERIFY(msg->isTopLevel());
 }
 
